function [ OUTx,OUTy,OUThist ] = diverg_hist_norm( ti,div,nbin,colors )
% Calculating the two-dimensional histogram of a matrix. The histogram has been 
% normalized by using the total number of points in the incoming div dataset.
% 
% Explanation of input parameters:
%  ti      extra part for the plot title
%  opt     data options from the data file
%  div     (i,x,y) points of divergence points (i is neutron number)
%  nbin    number of bins as [xbins ybins]
%  colors  the caxis vector
% 
% Explanation of output variables:
%  Ox       x-values corresponding to the first axis numbers in the histogram
%  Oy       y-values corresponding to the second axis numbers in the histogram
%  Ohist    the histogram itself, as a nbin(1) x nbin(2) matrix

% Output what the routine is doing
fprintf('  Calculating histogram of divergencies...\n\n')

% Calculate edges
s0x = -1.1*pi/2;
s1x =  1.1*pi/2;
s0y = -1.1*pi/2;
s1y =  1.1*pi/2;

nbinx = nbin(1);
nbiny = nbin(2);

edgesx      = s0x:s1x/nbinx:s1x;
edgesx_mean = (s0x:s1x/nbinx:s1x-s1x/nbinx) + (s1x-s0x)/2/nbinx;
edgesy      = s0y:s1y/nbiny:s1y;
edgesy_mean = (s0y:s1y/nbiny:s1y-s1y/nbiny) + (s1y-s0y)/2/nbiny;

edges = cell([1,2]);
edges{1} = edgesx;
edges{2} = edgesy;

planepositions = [div(:,2),div(:,3)];

% Calculate histogram and normalize it
N = hist3(planepositions,'Edges',edges);
N = N/length(planepositions(:,1))*10^4;
N = transpose(N);

% Plot the histogram 
figure; hold on
pcolor(edgesx_mean,edgesy_mean,N(1:end-1,1:end-1))
axis([s0x s1x s0y s1y])
shading flat
title(['Divergencies. ',ti])
xlabel('x-direction divergency [rad]')
ylabel('y-direction divergency [rad]')
caxis(colors)
colorbar

% Save output values
OUTx     = edgesx_mean(1:end);
OUTy     = edgesy_mean(1:end);
OUThist  = N(1:end-1,1:end-1);

end

