function [ Ox,Oy,Ohist ] = pl_insec_hist( ti,opt,pl_xy,z_pl,norm,nbin,colors )
% Calculating the two-dimensional histogram of a matrix, and plotting it with
% the moderator size taken from the opt variable.
% 
% Explanation of input parameters:
%  ti       extra part for the plot title
%  opt      data options from the data file
%  pl_xy    (i,x,y) points of intersection in the plane (i is neutron number)
%  z_pl     the z-value where the plane is placed
%  norm     normalization constant
%  nbin     number of bins as [xbins ybins]
%  colors   the caxis vector
% 
% Explanation of output variables:
%  Ox       x-values corresponding to the first axis numbers in the histogram
%  Oy       y-values corresponding to the second axis numbers in the histogram
%  Ohist    the histogram itself, as a nbin(1) x nbin(2) matrix

% Output what the routine is doing
fprintf(['  Calculating histogram of intersections of a plane with ',...
         'z = ',num2str(z_pl),' = zmax + ',num2str(z_pl-opt(3)),'...\n\n'])

% Calculate edges
s0x = 0-0.25*opt(1);
s1x = 1.25*opt(1);
s0y = 0-0.25*opt(2);
s1y = 1.25*opt(2);

nbinx = nbin(1);
nbiny = nbin(2);

edgesx      = s0x:s1x/nbinx:s1x;
edgesx_mean = (s0x:s1x/nbinx:s1x-s1x/nbinx) + (s1x-s0x)/2/nbinx;
edgesy      = s0y:s1y/nbiny:s1y;
edgesy_mean = (s0y:s1y/nbiny:s1y-s1y/nbiny) + (s1y-s0y)/2/nbiny;

edges = cell([1,2]);
edges{1} = edgesx;
edges{2} = edgesy;

planepositions = [pl_xy(:,2),pl_xy(:,3)];

% Calculate histogram and normalize it
N = hist3(planepositions,'Edges',edges);
N = transpose(N) * norm;

% Plot the histogram along with the moderator size
figure; hold on
pcolor(edgesx_mean,edgesy_mean,N(1:end-1,1:end-1))
shading flat
rectangle('Position',[0,0,opt(1),opt(2)])
axis([s0x s1x s0y s1y])
title(['Intersections of the z = ',num2str(z_pl),' plane. ',ti])
xlabel('x-direction')
ylabel('y-direction')
colorbar
caxis(colors)

% Save output values
Ox    = edgesx_mean(1:end);
Oy    = edgesy_mean(1:end);
Ohist = N(1:end-1,1:end-1);

end

