function [ intdatOUT ] = plot_r_old( ti,opt,data,Emax,numP )
% Plot a chosen number of points, with energy below Emax, in a scatter plot, 
% where the moderator size is shown as a box.
% 
% Explanation of input parameters:
%  ti         extra text for the plot title
%  opt        options from the datafile (used to make moderator box)
%  data       data from datafile
%  Emax       the program plots only points with neutron energy less than Emax
%  numP       number of points to plot
% 
% Explanation of output variables:
%  intdatOUT  the actual points chosen to be plotted

% Checking for correct input
if ( numP > length(data(:,8)) )
    numP = length(data(:,8));
    fprintf(['ERROR: The wanted number of points was larger than the ',...
             'number of accessible \npoints in the dataset! The number has ',...
             'set to the largest possible number: ',num2str(numP),'\n\n'])
end

% Defining moderator faces to put in the plot
xmin = 0;  xmax = opt(1);
ymin = 0;  ymax = opt(2);
zmin = 0;  zmax = opt(3);

xpatch1 = [xmax xmax xmin xmin];
ypatch1 = [ymin ymin ymin ymin];
zpatch1 = [zmin zmax zmax zmin];
xpatch2 = [xmax xmin xmin xmax];
ypatch2 = [ymin ymin ymax ymax];
zpatch2 = [zmax zmax zmax zmax];
xpatch3 = [xmin xmin xmin xmin];
ypatch3 = [ymin ymax ymax ymin];
zpatch3 = [zmax zmax zmin zmin];
xpatch4 = [xmin xmax xmax xmin];
ypatch4 = [ymin ymin ymax ymax];
zpatch4 = [zmin zmin zmin zmin];
xpatch5 = [xmax xmax xmax xmax];
ypatch5 = [ymin ymin ymax ymax];
zpatch5 = [zmin zmax zmax zmin];
xpatch6 = [xmax xmin xmin xmax];
ypatch6 = [ymax ymax ymax ymax];
zpatch6 = [zmax zmax zmin zmin];

% Initialize figure
figure

% Plot the moderator faces
patch(xpatch1,ypatch1,zpatch1,'r','FaceAlpha',0)       
patch(xpatch2,ypatch2,zpatch2,'y','FaceAlpha',0)
patch(xpatch3,ypatch3,zpatch3,'g','FaceAlpha',0)
patch(xpatch4,ypatch4,zpatch4,'c','FaceAlpha',0)
patch(xpatch5,ypatch5,zpatch5,'b','FaceAlpha',0)
patch(xpatch6,ypatch6,zpatch6,'k','FaceAlpha',0)

hold on

title(['Last point for the neutrons. Emax = ',num2str(Emax),' eV. ',ti])
xlabel('x-direction')
ylabel('y-direction')
zlabel('z-direction')

% Set axes
xl = xmax - xmin;
yl = ymax - ymin;
zl = zmax - zmin;
axis([xmin-xl/10 xmax+xl/10 ymin-yl/10 ymax+yl/10 zmin-zl/10 zmax+zl/10])

% Set viewing angle
Az = 39; El = 26;  
view(Az,El)

% Find the points to plot
k1 = 0;
intdat = zeros(numP,3);
for i = 1:length(data(:,1))
    if (data(i,8) <= Emax)
        if (k1 < numP)
            k1 = k1 + 1;
            intdat(k1,1) = data(i,2);
            intdat(k1,2) = data(i,3);
            intdat(k1,3) = data(i,4);
        end
    end
end

% Check for errors
if ( k1 < numP )
    fprintf(['ERROR: The wanted number of points was larger than the ',...
             'number of accessible \npoints with the right energy. The ',...
             'number has been set to the largest possible: ',num2str(k1),...
             '\n\n'])
end

% Plot the points
scatter3(intdat(1:k1,1),intdat(1:k1,2),intdat(1:k1,3),'.','CData',intdat(1:k1,3))

% Save the output variable
intdatOUT = intdat(1:k1,:);

end