function [ opt,data ] = read_data( file,bool,np )
% Reads the from a full simulation data file.
% 
% Explanation of input parameters:
%  file         name of file (without the ".dat")
%               example: 'largeflat'
%  bool         boolean (1 or 0)
%  np           number of wanted points if bool=1
% 
% Overview of the opt array:
%  opt(1)       xmax
%  opt(2)       ymax
%  opt(3)       zmax
%  opt(4)       sphere center x
%  opt(5)       sphere center y
%  opt(6)       sphere center z
%  opt(7)       sphere radius
%  opt(8)       start energy of neutrons
%  opt(9)       thermal energy
%  opt(10)      number of simulated neutrons in output
%  opt(11)      number of simulated neutrons in total
%  opt(12)      not used here (debugging of simulation code)
%  opt(13)      not used here (debugging of simulation code)
%  opt(14)      not used here (debugging of simulation code)
%  opt(15)      not used here (debugging of simulation code)
%  opt(16)      not used here (debugging of simulation code)
% 
% Overview of the data array:
%  data(:,1)    neutron number
%  data(:,2)    neutron position in x
%  data(:,3)    neutron position in y
%  data(:,4)    neutron position in z
%  data(:,5)    neutron direction in x
%  data(:,6)    neutron direction in y
%  data(:,7)    neutron direction in z
%  data(:,8)    neutron energy
%  data(:,9)    total traveled distance
%  data(:,10)   number of interactions
%  data(:,11)   number of mirrorings

% Open file and read in simulation options
fprintf(['Working with datafile ',file,'.dat...\n\n'])
fid = fopen([file,'.dat']);
datao = cell2mat(textscan(fid,'%n','headerlines',0));
fclose(fid);

% Save the options from the datafile into the correct array
opt = datao(1:16);

% Print the found options
if (bool == 1)
    fprintf(['  In total, ',num2str(opt(10)),' neutrons were output,'])
    fprintf([' but only the first ',num2str(np),' has been read in.\n'])
elseif (bool == 0)
    fprintf(['  In total, ',num2str(opt(10)),' neutrons were output.\n'])
end
fprintf(['  In total, ',num2str(opt(11)),' neutrons were actually ',...
         'simulated.\n\n'])
fprintf('  The moderator has   ')
fprintf(['    xmax = ',num2str(opt(1)),''])
fprintf(['    ymax = ',num2str(opt(2)),''])
fprintf(['    zmax = ',num2str(opt(3)),'\n'])
fprintf('  The sphere has      ')
fprintf(['    x = ',num2str(opt(4)),''])
fprintf(['    y = ',num2str(opt(5)),''])
fprintf(['    z = ',num2str(opt(6)),''])
fprintf(['    r = ',num2str(opt(7)),'\n'])
fprintf('  The neutrons start with energy      ')
fprintf(['    E0 = ',num2str(opt(8)),'\n\n'])

% Open file and read data
fid = fopen([file,'.dat']);                                %open file again
datat = cell2mat(textscan(fid,'%n %n %n %n %n %n %n %n %n %n %n %n %n %n',... 
                'headerlines',16));
fclose(fid);                                               %close file again

% Decide how many datapoints is to be used
if (bool == 0)                                             %check type
    imax = length(datat(:,1));                             %full dataset
elseif (bool == 1)
    imax = np;                                             %only start of data
end

data = datat(1:imax,:);

end