function [ opt,div ] = read_data_div6( file,bool,np )
% Read in divergence data.
% 
% Explanation of input parameters:
%  file        file name in the data directory
%  bool        if 1, only read in the np points; if 0, read all
%  np          number of points to read in if bool = 1
% 
% Overview of the opt array:
%  opt         plane z-position for divergence calculation
% 
% Overview of the div array:
%  div(:,1)    neutron number
%  div(:,2)    neutron x-divergence
%  div(:,3)    neutron y-divergence
%  div(:,4)    x
%  div(:,5)    y
%  div(:,6)    z

% Open file and read in simulation options
fprintf(['Working with div datafile ',file,'.dat...\n\n'])
fid = fopen([file,'.dat']);                              
datao = cell2mat(textscan(fid,'%n','headerlines',0));    
fclose(fid);                                             

% Save the options from the datafile
opt = datao(1);

% Print the found options
fprintf(['  The plane is positioned at z = ',num2str(opt),'.\n\n'])

% Open file and read data
fid = fopen([file,'.dat']); 
datat = cell2mat(textscan(fid,'%n %n %n %n %n %n','headerlines',1));
fclose(fid);

% Decide how many datapoints is to be used
if (bool == 0)                                     %check type
    imax = length(datat(:,1));                     %full dataset
elseif (bool == 1)
    imax = np;                                     %only start of data
end

% Save the output variable
div = datat(1:imax,:);

end

