function [ path_opt,paths ] = read_data_path( ti,file,bool,incr )
% Read in path data and plot them (all at once or incremental with user 
% clicking a button to plot more).
% 
% Explanation of input parameters:
%  ti            extra text for the plot title
%  file          file name in the data directory
%  bool          if 1, plot incrementially; if 0, plot all
%  incr          number of points to plot at a time if bool = 1
% 
% Overview of the path_opt array:
%  path_opt(1)   path number
%  path_opt(2)   neutron number
%  path_opt(3)   xmax of moderator
%  path_opt(4)   ymax of moderator
%  path_opt(5)   zmax of moderator
%  path_opt(6)   x of sphere center
%  path_opt(7)   y of sphere center
%  path_opt(8)   z of sphere center
%  path_opt(9)   radius of sphere
%  path_opt(10)  start energy
%  path_opt(11)  thermal energy
% 
% Overview of the paths array:
%  paths(:,1)    point number
%  paths(:,2)    point x-position
%  paths(:,3)    point y-position
%  paths(:,4)    point z-position
%  paths(:,5)    dist (for debugging)
%  paths(:,6)    neutron energy

% Open file and read in path data options
fid = fopen([file,'.dat']);
path_opt_temp = cell2mat(textscan(fid,'%n %n %n %n %n %n %n %n %n %n %n',...
                         'headerlines',0));
fclose(fid);

path_opt = path_opt_temp(1,:);

% Open file and read in path data
fid = fopen([file,'.dat']);
paths = cell2mat(textscan(fid,'%n %n %n %n %n %n','headerlines',1));
fclose(fid);

% Defining moderator faces to put in the plot
xmin = 0;  xmax = path_opt(3);
ymin = 0;  ymax = path_opt(4);
zmin = 0;  zmax = path_opt(5);

xpatch1 = [xmax xmax xmin xmin];
ypatch1 = [ymin ymin ymin ymin];
zpatch1 = [zmin zmax zmax zmin];
xpatch2 = [xmax xmin xmin xmax];
ypatch2 = [ymin ymin ymax ymax];
zpatch2 = [zmax zmax zmax zmax];
xpatch3 = [xmin xmin xmin xmin];
ypatch3 = [ymin ymax ymax ymin];
zpatch3 = [zmax zmax zmin zmin];
xpatch4 = [xmin xmax xmax xmin];
ypatch4 = [ymin ymin ymax ymax];
zpatch4 = [zmin zmin zmin zmin];
xpatch5 = [xmax xmax xmax xmax];
ypatch5 = [ymin ymin ymax ymax];
zpatch5 = [zmin zmax zmax zmin];
xpatch6 = [xmax xmin xmin xmax];
ypatch6 = [ymax ymax ymax ymax];
zpatch6 = [zmax zmax zmin zmin];

% Initialize figure
figure

% Plot the moderator faces
patch(xpatch1,ypatch1,zpatch1,'r','FaceAlpha',0)
patch(xpatch2,ypatch2,zpatch2,'y','FaceAlpha',0)
patch(xpatch3,ypatch3,zpatch3,'g','FaceAlpha',0)
patch(xpatch4,ypatch4,zpatch4,'c','FaceAlpha',0)
patch(xpatch5,ypatch5,zpatch5,'b','FaceAlpha',0)
patch(xpatch6,ypatch6,zpatch6,'k','FaceAlpha',0)

hold on

title(['From datafile ',file,'. ',ti])
xlabel('x-direction')
ylabel('y-direction')
zlabel('z-direction')

% Set axes
xl = xmax - xmin;
yl = ymax - ymin;
zl = zmax - zmin;
axis([xmin-xl/10 xmax+xl/10 ymin-yl/10 ymax+yl/10 zmin-zl/10 zmax+zl/10])

% Set viewing angle
Az = 39; El = 26;
view(Az,El)

% Plot path
if (bool == 0)
    plot3(paths(:,2),paths(:,3),paths(:,4),'-')
else if (bool == 1)
    imax = length(paths(:,2));
    plot3(paths(1:incr,2),paths(1:incr,3),paths(1:incr,4),'-')
    
    fprintf('                               ')
    for i = incr:incr:imax
        fprintf('\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b')
        if (i + incr <= length(paths(:,2)))
            plot3(paths(i:i+incr,2),paths(i:i+incr,3),paths(i:i+incr,4),'-')
        else
            plot3(paths(i:imax,2),paths(i:imax,3),paths(i:imax,4),'-')
        end
        fprintf('Press any key to continue...')
        pause
    end
end

fprintf('\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b')

end