function [ z_pl,pl_xy ] = read_data_plxy( file,bool,np )
% Read in intersection data.
% 
% Explanation of input parameters:
%  file        file name in the data directory
%  bool        if 1, only read in the np points; if 0, read all
%  np          number of points to read in if bool = 1
% 
% Explanation of output variables:
%  z_pl        plane z-position for intersection calculation
%  pl_xy(:,1)  neutron number
%  pl_xy(:,2)  neutron x-position on plane
%  pl_xy(:,3)  neutron y-position on plane

% Open file and read in data file options
fprintf(['Working with intersection datafile ',file,'.dat...\n\n'])
fid = fopen([file,'.dat']);
datao = cell2mat(textscan(fid,'%n','headerlines',0));
fclose(fid);

% Save the options from the datafile
z_pl = datao(1);

% Print the found options
fprintf(['  The plane is positioned at z = ',num2str(z_pl),'.\n\n'])

% Open file and read data
fid = fopen([file,'.dat']);
datat = cell2mat(textscan(fid,'%n %n %n','headerlines',1));
fclose(fid);

% Decide how many datapoints is to be used
if (bool == 0)                       %check type
    imax = length(datat(:,1));       %full dataset
elseif (bool == 1)
    imax = np;                       %only start of data
end

% Save the output variable
pl_xy = datat(1:imax,:);

end

