function [ points ] = read_data_sideinsec( file,bool,np )
% Read in side intersection data.
% 
% Explanation of input parameters:
%  file          file name in the data directory
%  bool          if 1, only read in the np points; if 0, read all
%  np            number of points to read in if bool = 1
% 
% Overview of the points array:
%  points(:,1)   neutron number
%  points(:,2)   neutron x-position on plane
%  points(:,3)   neutron y-position on plane
%  points(:,4)   which plane was intersected (1, 2, 3 or 4)

% Open file and read data
fprintf(['Working with side intersection datafile ',file,'.dat...\n\n'])
fid = fopen([file,'.dat']);
datat = cell2mat(textscan(fid,'%n %n %n %n','headerlines',0));
fclose(fid);

% Decide how many datapoints is to be used
if (bool == 0)                                  %check type
    imax = length(datat(:,1));                  %full dataset
elseif (bool == 1)
    imax = np;                                  %start of data
end

% Save the output variable
points = datat(1:imax,:);

end

