function [ OUTx,OUTz,OUThist ] = sideinsec_hist( ti,opt,points,norm,nbin,colors )
% Calculating the two-dimensional histogram of a matrix, and plotting it with
% the moderator size taken from the opt variable.
%
% Explanation of input parameters:
%  ti       extra part for the plot title
%  opt      data options from the data file
%  points   (i,x,z,I) points of intersection in the plane (i is neutron number)
%  norm     normalization constant
%  nbin     number of bins as [xbins zbins]
%  colors   the caxis vector
% 
% Explanation of output variables:
%  Ox       x/y-values corresponding to the first axis numbers in the histogram
%  Oz       z-values corresponding to the second axis numbers in the histogram
%  Ohist    the histogram itself, as a nbin(1) x nbin(2) matrix

% Output what the routine is doing
fprintf('  Calculating histogram of intersections of moderator side...\n\n')

% Calculate edges
s0x = 0-0.5*opt(1);
s1x = 1.5*opt(1);
s0z = 0-0.5*opt(3);
s1z = 1.5*opt(3);

nbinx = nbin(1);
nbinz = nbin(2);

edgesx      = s0x:s1x/nbinx:s1x;
edgesx_mean = (s0x:s1x/nbinx:s1x-s1x/nbinx) + (s1x-s0x)/2/nbinx;
edgesz      = s0z:s1z/nbinz:s1z;
edgesz_mean = (s0z:s1z/nbinz:s1z-s1z/nbinz) + (s1z-s0z)/2/nbinz;

edges = cell([1,2]);
edges{1} = edgesx;
edges{2} = edgesz;

planepositions = [points(:,2),points(:,3)];

% Calculate histogram and normalize it
N = hist3(planepositions,'Edges',edges);
N = transpose(N) * norm;

% Plot the histogram along with the moderator size
figure; hold on
pcolor(edgesx_mean,edgesz_mean,N(1:end-1,1:end-1))
shading flat
rectangle('Position',[0,0,opt(1),opt(3)])
axis([ s0x s1x s0z s1z])
title(['Intersections of the moderator side. ',ti])
xlabel('x- and y-direction')
ylabel('z-direction')
colorbar
caxis(colors)

% Save output values
OUTx    = edgesx_mean(1:end);
OUTz    = edgesz_mean(1:end);
OUThist = N(1:end-1,1:end-1);

end

