%% Initial options

% Clear screen, old variables, etc.
clc
clear all
close all

% Set path to function directory
path_backup = path;
path(path_backup,'functions')

% Data directories
dd_data = '../../data/measurements/';
dd_path = '../../data/paths/';
dd_s1   = '../../data/sim/sph1/';  
dd_s2   = '../../data/sim/sph2/';  
dd_f    = '../../data/sim/flat/';  

%% Read in simulation data

% Number of datapoints to read in from the main datafiles
n_readin_s1 = 1000000;
n_readin_s2 = 1000000;
n_readin_f  = 1000000;

% Read in from simulation datafiles
[ opt_s1,data_s1 ] = read_data( [dd_s1,'data'],1,n_readin_s1 );
[ opt_s2,data_s2 ] = read_data( [dd_s2,'data'],1,n_readin_s2 );
[ opt_f,data_f ]   = read_data( [dd_f,'data'],1,n_readin_f );

% Read in from simulation datafiles (side files)
[ opts_s1,datas_s1 ] = read_data( [dd_s1,'datam'],1,n_readin_s1 );
[ opts_s2,datas_s2 ] = read_data( [dd_s2,'datam'],1,n_readin_s2 );
[ opts_f,datas_f ]   = read_data( [dd_f,'datam'],1,n_readin_f );

% Read in from intersection datafiles
[ zpl_s11,plxy_s11 ] = read_data_plxy( [dd_s1,'data_plxy69'],0,1 );
[ zpl_s15,plxy_s15 ] = read_data_plxy( [dd_s1,'data_plxy81'],0,1 );
[ zpl_s16,plxy_s16 ] = read_data_plxy( [dd_s1,'data_plxy93'],0,1 );
[ zpl_s17,plxy_s17 ] = read_data_plxy( [dd_s1,'data_plxy105'],0,1 );
[ zpl_s21,plxy_s21 ] = read_data_plxy( [dd_s2,'data_plxy69'],0,1 );
[ zpl_s25,plxy_s25 ] = read_data_plxy( [dd_s2,'data_plxy81'],0,1 );
[ zpl_s26,plxy_s26 ] = read_data_plxy( [dd_s2,'data_plxy93'],0,1 );
[ zpl_s27,plxy_s27 ] = read_data_plxy( [dd_s2,'data_plxy105'],0,1 );
[ zpl_f1,plxy_f1 ]   = read_data_plxy( [dd_f,'data_plxy69'],0,1 );
[ zpl_f5,plxy_f5 ]   = read_data_plxy( [dd_f,'data_plxy81'],0,1 );
[ zpl_f6,plxy_f6 ]   = read_data_plxy( [dd_f,'data_plxy93'],0,1 );
[ zpl_f7,plxy_f7 ]   = read_data_plxy( [dd_f,'data_plxy105'],0,1 );

% Read in from side-intersection datafiles
[ sint_s1 ] = read_data_sideinsec( [dd_s1,'sideintersec'],0,1 );
[ sint_f ]  = read_data_sideinsec( [dd_f,'sideintersec'],0,1 );

% Read in from divergence datafiles
[ ~,divsph_s1 ]    = read_data_div6( [dd_s1,'divsph'],0,1 );
[ ~,divhsphR_s1 ]  = read_data_div6( [dd_s1,'divhalfsphR'],0,1 );
[ ~,divsph_s2 ]    = read_data_div6( [dd_s2,'divsph'],0,1 );
[ ~,divhsphR_s2t ] = read_data_div6( [dd_s2,'divhalfsphR'],0,1 );

% Read in and plot paths
[ path_optf,pathsf ] = read_data_path( 'Short path',[dd_path,'few'],0,1 )
[ path_optm,pathsm ] = read_data_path( 'Long path',[dd_path,'many'],0,1 )

%% Make normalization factors

% Factor to make the numbers easier to work with
fac = 10^7;

% Define the normalization factors for the different datasets
%  S  number of neutrons simulated in total - opt(11)
%  U  number of neutrons written to datafile - opt(10)
%  I  number of neutrons read in from the datafile - num_readin
%  U = kS, K = U/S, I = kS', S' = I/k = IS/U
%  real intensity = intensity/S' = intensity U/(IS)
norm_s1 = fac * opt_s1(10) / ( n_readin_s1 * opt_s1(11) );
norm_s2 = fac * opt_s2(10) / ( n_readin_f * opt_s2(11) );
norm_f  = fac * opt_f(10) / ( n_readin_f * opt_f(11) );

% Normalization factors about neutrons going through bottom (only used at conv)
normb_s1 = opt_s1(11)/( opt_s1(11) - opt_s1(10) - length(sint_s1(:,1)) * ...
           opt_s1(11) / datas_s1(end,1) );
normb_f  = opt_f(11)/( opt_f(11) - opt_f(10) - length(sint_f(:,1)) * ...
           opt_f(11) / datas_f(end,1) );


%% Plot intersection data as histograms

% Initial options
bin  = [100 100];    %number of bins in histograms [x y]
cax  = [0 435];      %over-all axis of intensity color

% Calculate histograms
[ x_s11,y_s11,hist_s11 ] = pl_insec_hist( 'Sph1',opt_s1,plxy_s11,zpl_s11,...
                                           norm_s1,bin,cax );
[ x_s15,y_s15,hist_s15 ] = pl_insec_hist( 'Sph1',opt_s1,plxy_s15,zpl_s15,...
                                           norm_s1,bin,cax );
[ x_s16,y_s16,hist_s16 ] = pl_insec_hist( 'Sph1',opt_s1,plxy_s16,zpl_s16,...
                                           norm_s1,bin,cax );
[ x_s17,y_s17,hist_s17 ] = pl_insec_hist( 'Sph1',opt_s1,plxy_s17,zpl_s17,...
                                           norm_s1,bin,cax );
[ x_s21,y_s21,hist_s21 ] = pl_insec_hist( 'Sph2',opt_s2,plxy_s21,zpl_s21,...
                                           norm_s2,bin,cax );
[ x_s25,y_s25,hist_s25 ] = pl_insec_hist( 'Sph2',opt_s2,plxy_s25,zpl_s25,...
                                           norm_s2,bin,cax );
[ x_s26,y_s26,hist_s26 ] = pl_insec_hist( 'Sph2',opt_s2,plxy_s26,zpl_s26,...
                                           norm_s2,bin,cax );
[ x_s27,y_s27,hist_s27 ] = pl_insec_hist( 'Sph2',opt_s2,plxy_s27,zpl_s27,...
                                           norm_s2,bin,cax );
[ x_f1,y_f1,hist_f1 ]    = pl_insec_hist( 'Flat',opt_f,plxy_f1,zpl_f1,norm_f,...
                                           bin,cax );
[ x_f5,y_f5,hist_f5 ]    = pl_insec_hist( 'Flat',opt_f,plxy_f5,zpl_f5,norm_f,...
                                           bin,cax );
[ x_f6,y_f6,hist_f6 ]    = pl_insec_hist( 'Flat',opt_f,plxy_f6,zpl_f6,norm_f,...
                                           bin,cax );
[ x_f7,y_f7,hist_f7 ]    = pl_insec_hist( 'Flat',opt_f,plxy_f7,zpl_f7,norm_f,...
                                           bin,cax );

%% Plot where the neutrons come from

% Initial options
Emax = 1;      %maximum energy to work with
numP = 5000;   %number of points to plot

% Plot the scatter plots
[ ~ ] = plot_r_old( 'Sph1',opt_s1,data_s1,Emax,numP );
[ ~ ] = plot_r_old( 'Sph2',opt_s2,data_s2,Emax,numP );
[ ~ ] = plot_r_old( 'Flat',opt_f,data_f,Emax,numP );

%% Plot side-intersection data

% Initial options
bin = [100 100];     %number of bins in histograms [x y]
cax = [0 353];       %over-all axis of intensity color

% Calculate histograms
[ x_s1,z_s1,hist_s1 ] = sideinsec_hist( 'Sph1',opt_s1,sint_s1,norm_s1,bin,cax );
[ x_f,z_f,hist_f ]    = sideinsec_hist( 'Flat',opt_f,sint_f,norm_f,bin,cax );

%% Plot divergence data as histograms

% Initial options
bin = [50 50];       %number of bins in histograms [x y]
cax = [0 353];       %over-all axis of intensity color

% Calculate histograms
[ x_sph_s1,y_sph_s1,hist_sph_s1 ]       = ...
  diverg_hist_norm( 'Sph1',divsph_s1,bin,cax );
[ x_hsphR_s1,y_hsphR_s1,hist_hsphR_s1 ] = ...
  diverg_hist_norm( 'Sph1, halfsphR',divhsphR_s1,bin,cax );
[ x_sph_s2,y_sph_s2,hist_sph_s2 ]       = ...
  diverg_hist_norm( 'Sph2',divsph_s2,bin,cax );
[ x_hsphR_s2,y_hsphR_s2,hist_hsphR_s2 ] = ...
  diverg_hist_norm( 'Sph2, halfsphR',divhsphR_s2t,bin,cax );

% Plot as a sum in only one dimension instead
[ hist_sph_s1_1D ]   = hist2Dtohist1D( 'Sph1',x_sph_s1,hist_sph_s1 )
[ hist_hsphR_s1_1D ] = hist2Dtohist1D( 'Sph1, halfsphR',x_hsphR_s1,hist_hsphR_s1 )
[ hist_sph_s2_1D ]   = hist2Dtohist1D( 'Sph2',x_sph_s2,hist_sph_s2 )
[ hist_hsphR_s2_1D ] = hist2Dtohist1D( 'Sph2, halfsphR',x_hsphR_s2,hist_hsphR_s2 )

% Plot as two plots
figure
plot(x_sph_s1,hist_sph_s1_1D,'-b');   hold on
plot(x_hsphR_s1,hist_hsphR_s1_1D,'-g')
title('Histogram over x-divergencies')
xlabel('x-divergence [rad]')
ylabel('number of neutrons in bin (for all y-divergencies)')
legend('Sph1','Sph1, halfsphR')
grid

figure
plot(x_sph_s2,hist_sph_s2_1D,'-b');   hold on
plot(x_hsphR_s2,hist_hsphR_s2_1D,'-g')
title('Histogram over x-divergencies')
xlabel('x-divergence [rad]')
ylabel('number of neutrons in bin (for all y-divergencies)')
legend('Sph2','Sph2, halfsphR')
grid

%% Read in convoluted simulation data

% Factor to get convolution data down to the measurement count-rates
factor = 0.3*10^(-3); 

% Total read-in factors
f_s1 = factor * norm_s1; 
f_f  = factor * norm_f;  

% Read in from convolution datafiles
[ x_s1,N_s1 ] = read_data_conv( [dd_s1,'data_convr'],f_s1 );
[ x_f,N_f ]   = read_data_conv( [dd_f,'data_convr'],f_f );

%% Read in measured data

% Dark count measurement
[ ~, ~, ~, ~, ~, ~, N_mdc, dN_mdc ] = read_realdata( [dd_data,'dc01'] );

fprintf(['  Dark count has been found to be:  ',num2str(N_mdc(1)),' +/- ',...
         num2str(dN_mdc(1)),'\n\n'])

% Background measurements
[ ~, ~, ~, ~, ~, ~, N_mbg, dN_mbg ] = read_realdata( [dd_data,'bg01'] );

fprintf(['  Background above flat1 moderator: ',num2str(N_mbg(1)),' +/- ',...
         num2str(dN_mbg(1)),'\n'])
fprintf(['  Background above sph1 moderator:  ',num2str(N_mbg(2)),' +/- ',...
         num2str(dN_mbg(2)),'\n\n'])

% Measurements over the sph1 moderator
[ x_ms1, dx_ms1, T_ms1, dT_ms1, N_T_ms1, dN_T_ms1, Nin_ms1, dNin_ms1 ] = ...
  read_realdata_wh( [dd_data,'sph101'] );

% Measurements over the flat moderator
[ x_mf, dx_mf, T_mf, dT_mf, N_T_mf, dN_T_mf, Nin_mf, dNin_mf ] = ...
  read_realdata_wh( [dd_data,'flat01'] );

% Measurements over the cyl1 moderator
[ x_mc1, dx_mc1, c1_de, c1_dde, T_mc1, dT_mc1, N_T_mc1, dN_T_mc1, Nin_mc1, ...
  dNin_mc1 ] = read_realdata_cyl( [dd_data,'cyl01'] );

% Correct data with background measurements
BGN               = ( N_mbg(1) + N_mbg(2) ) / 2;
dBGN              = sqrt( dN_mbg(1)^2 + dN_mbg(2)^2 ) / 2;
[ N_ms1, dN_ms1 ] = removebg( Nin_ms1, dNin_ms1, BGN, dBGN );
[ N_mf, dN_mf ]   = removebg( Nin_mf, dNin_mf, BGN, dBGN );
[ N_mc1, dN_mc1 ] = removebg( Nin_mc1, dNin_mc1, BGN, dBGN );

%% Plot measured data along with the convoluted simulation data

figure
rectangle('Position',[5.93,0,22-5.76-5.93,8]); hold on
errorbar( x_ms1, N_ms1, dN_ms1, '.b' )
plot(x_s1,N_s1,'-b')
errorbar( x_mf, N_mf, dN_mf, '.g' )
plot(x_f,N_f,'-g')
title('Neutron flux for two moderators')
xlabel('Position along moderator middle, x [cm]')
ylabel('Flux of neutrons, I [cpm]')
legend('Sph1 moderator','Simulated intensity','Flat moderator','Simulated intensity')

%% Final options

% Set path back to normal
path(path_backup)
